@@ -77,6 +77,17 @@ class QEOM(ExcitedStatesSolver):
             )
         self._excitations = excitations
 
+    @property
+    def solver(self):
+        return self._gsc.solver
+
+    def get_qubit_operators(
+        self,
+        problem: BaseProblem,
+        aux_operators: Optional[ListOrDictType[Union[SecondQuantizedOp, PauliSumOp]]] = None,
+    ) -> Tuple[PauliSumOp, Optional[ListOrDictType[PauliSumOp]]]:
+        return self._gsc.get_qubit_operators(problem, aux_operators)
+
     def solve(
         self,
         problem: BaseProblem,
@@ -208,8 +219,7 @@ class QEOM(ExcitedStatesSolver):
         def _build_one_sector(available_hopping_ops, untapered_op, z2_symmetries):
 
             to_be_computed_list = []
-            for idx, _ in enumerate(mus):
-                m_u = mus[idx]
+            for idx, m_u in enumerate(mus):
                 n_u = nus[idx]
                 left_op = available_hopping_ops.get(f"E_{m_u}")
                 right_op_1 = available_hopping_ops.get(f"E_{n_u}")
@@ -238,7 +248,7 @@ class QEOM(ExcitedStatesSolver):
                     all_matrix_operators[f"v_{m_u}_{n_u}"] = v_mat_op
 
         try:
-            z2_symmetries = self._gsc.qubit_converter.z2symmetries  # type: ignore
+            z2_symmetries = self._gsc.qubit_converter.z2symmetries
         except AttributeError:
             z2_symmetries = Z2Symmetries([], [], [])
 
@@ -353,8 +363,7 @@ class QEOM(ExcitedStatesSolver):
         m_mat_std, v_mat_std, q_mat_std, w_mat_std = 0.0, 0.0, 0.0, 0.0
 
         # evaluate results
-        for idx, _ in enumerate(mus):
-            m_u = mus[idx]
+        for idx, m_u in enumerate(mus):
             n_u = nus[idx]
 
             q_mat[m_u][n_u] = (
@@ -400,7 +409,6 @@ class QEOM(ExcitedStatesSolver):
             )
 
         # these matrices are numpy arrays and therefore have the ``shape`` attribute
-        # pylint: disable=unsubscriptable-object
         q_mat = q_mat + q_mat.T - np.identity(q_mat.shape[0]) * q_mat
         w_mat = w_mat + w_mat.T - np.identity(w_mat.shape[0]) * w_mat
         m_mat = m_mat + m_mat.T - np.identity(m_mat.shape[0]) * m_mat
@@ -411,10 +419,10 @@ class QEOM(ExcitedStatesSolver):
         m_mat = np.real(m_mat)
         v_mat = np.real(v_mat)
 
-        q_mat_std = q_mat_std / float(size ** 2)
-        w_mat_std = w_mat_std / float(size ** 2)
-        m_mat_std = m_mat_std / float(size ** 2)
-        v_mat_std = v_mat_std / float(size ** 2)
+        q_mat_std = q_mat_std / float(size**2)
+        w_mat_std = w_mat_std / float(size**2)
+        m_mat_std = m_mat_std / float(size**2)
+        v_mat_std = v_mat_std / float(size**2)
 
         logger.debug("\nQ:=========================\n%s", q_mat)
         logger.debug("\nW:=========================\n%s", w_mat)
@@ -442,7 +450,6 @@ class QEOM(ExcitedStatesSolver):
         logger.debug("Diagonalizing qeom matrices for excited states...")
         a_mat = np.matrixlib.bmat([[m_mat, q_mat], [q_mat.T.conj(), m_mat.T.conj()]])
         b_mat = np.matrixlib.bmat([[v_mat, w_mat], [-w_mat.T.conj(), -v_mat.T.conj()]])
-        # pylint: disable=too-many-function-args
         res = linalg.eig(a_mat, b_mat)
         # convert nan value into 0
         res[0][np.where(np.isnan(res[0]))] = 0.0
