@@ -1,6 +1,6 @@
 # This code is part of Qiskit.
 #
-# (C) Copyright IBM 2021.
+# (C) Copyright IBM 2021, 2022.
 #
 # This code is licensed under the Apache License, Version 2.0. You may
 # obtain a copy of this license in the LICENSE.txt file in the root directory
@@ -24,3 +24,15 @@ Operators for different systems such as fermionic, vibrational and spin.
    second_quantization
 
 """
+
+from ..deprecation import warn_deprecated, DeprecatedType, NatureDeprecationWarning
+
+warn_deprecated(
+    "0.5.0",
+    old_type=DeprecatedType.PACKAGE,
+    old_name="qiskit_nature.operators",
+    new_type=DeprecatedType.PACKAGE,
+    new_name="qiskit_nature.second_q.operators",
+    stack_level=3,
+    category=NatureDeprecationWarning,
+)
