@@ -14,14 +14,13 @@
 
 import unittest
 from functools import partial
-from test import QiskitNatureTestCase
+from test import QiskitNatureDeprecatedTestCase
+
+import numpy as np
 
 from qiskit.opflow import PauliOp
 from qiskit.quantum_info import Pauli
 
-import numpy as np
-
-import qiskit
 from qiskit.algorithms import NumPyMinimumEigensolver, VQE
 from qiskit.utils import algorithm_globals, QuantumInstance, optionals
 import qiskit_nature.optionals as _optionals
@@ -47,7 +46,7 @@ from qiskit_nature.converters.second_quantization import QubitConverter
 from qiskit_nature.problems.second_quantization import ElectronicStructureProblem, BaseProblem
 
 
-class TestBOPES(QiskitNatureTestCase):
+class TestBOPES(QiskitNatureDeprecatedTestCase):
     """Tests of BOPES Sampler."""
 
     def setUp(self) -> None:
@@ -134,8 +133,10 @@ class TestBOPES(QiskitNatureTestCase):
     def test_vqe_bootstrap(self):
         """Test with VQE and bootstrapping."""
         qubit_converter = QubitConverter(JordanWignerMapper())
+        from qiskit_aer import Aer
+
         quantum_instance = QuantumInstance(
-            backend=qiskit.Aer.get_backend("aer_simulator_statevector"),
+            backend=Aer.get_backend("aer_simulator_statevector"),
             seed_simulator=self.seed,
             seed_transpiler=self.seed,
         )
@@ -170,8 +171,10 @@ class TestBOPES(QiskitNatureTestCase):
     @unittest.skipUnless(optionals.HAS_AER, "qiskit-aer is required to run this test")
     def test_h2_bopes_sampler_with_factory(self):
         """Test BOPES Sampler with Factory"""
+        from qiskit_aer import Aer
+
         quantum_instance = QuantumInstance(
-            backend=qiskit.Aer.get_backend("aer_simulator_statevector"),
+            backend=Aer.get_backend("aer_simulator_statevector"),
             seed_simulator=self.seed,
             seed_transpiler=self.seed,
         )
@@ -266,8 +269,10 @@ class TestBOPES(QiskitNatureTestCase):
         problem = ElectronicStructureProblem(driver)
 
         qubit_converter = QubitConverter(JordanWignerMapper(), z2symmetry_reduction=None)
+        from qiskit_aer import Aer
+
         quantum_instance = QuantumInstance(
-            backend=qiskit.Aer.get_backend("aer_simulator_statevector"),
+            backend=Aer.get_backend("aer_simulator_statevector"),
             seed_simulator=self.seed,
             seed_transpiler=self.seed,
         )
@@ -312,8 +317,10 @@ class TestBOPES(QiskitNatureTestCase):
         problem = ElectronicStructureProblem(driver)
 
         qubit_converter = QubitConverter(JordanWignerMapper(), z2symmetry_reduction=None)
+        from qiskit_aer import Aer
+
         quantum_instance = QuantumInstance(
-            backend=qiskit.Aer.get_backend("aer_simulator_statevector"),
+            backend=Aer.get_backend("aer_simulator_statevector"),
             seed_simulator=self.seed,
             seed_transpiler=self.seed,
         )
