@@ -17,7 +17,7 @@ import unittest
 import numpy as np
 from numpy.testing import assert_array_equal
 
-from retworkx import PyGraph, is_isomorphic
+from rustworkx import PyGraph, is_isomorphic
 
 from qiskit.utils import optionals as _optionals
 
